#[derive(Copy, Clone)]
pub enum SystemCallArgumentType {
    // Integer can be used to represent int, fd and size_t
    Integer,
    // String can be used to represent *buf
    String,
    // Address can be used to represent *statbuf
    Address,
    // None can be used if a syscall has fewer than 6 arguments
    None,
}

pub static TRACE_DESC: [usize; 98] = [
    0, 1, 2, 3, 5, 7, 8, 9, 17, 18, 19, 20, 22, 23, 32, 33, 40, 72, 73, 74, 75, 77, 78, 81, 85, 91,
    93, 187, 190, 193, 196, 199, 213, 217, 221, 232, 233, 240, 242, 243, 244, 245, 253, 254, 255,
    257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 275, 276, 277, 278,
    280, 281, 282, 283, 284, 285, 286, 287, 289, 290, 291, 292, 293, 294, 295, 296, 298, 300, 301,
    303, 304, 306, 308, 313, 316, 319, 320, 321, 322, 323, 326, 327, 328, 332,
];

pub static TRACE_FILE: [usize; 60] = [
    2, 4, 6, 21, 29, 76, 79, 80, 82, 83, 84, 85, 86, 87, 88, 89, 90, 92, 94, 132, 133, 134, 137,
    138, 155, 161, 163, 165, 166, 167, 168, 179, 188, 189, 191, 192, 194, 195, 197, 198, 235, 254,
    257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 280, 301, 303, 316, 332,
];

pub static TRACE_IPC: [usize; 12] = [29, 30, 31, 64, 65, 66, 67, 68, 69, 70, 71, 220];

pub static TRACE_NETWORK: [usize; 19] = [
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 181, 182, 299, 307,
];

pub static TRACE_PROCESS: [usize; 14] = [
    56, 57, 58, 59, 60, 61, 62, 129, 200, 231, 234, 247, 297, 322,
];

pub static TRACE_SIGNAL: [usize; 13] = [13, 14, 15, 34, 127, 128, 129, 130, 131, 200, 282, 289, 297];

pub static TRACE_MEMORY: [usize; 23] = [
    9, 10, 11, 12, 25, 26, 27, 28, 30, 149, 150, 151, 152, 206, 207, 216, 237, 238, 239, 256, 279,
    325, 329,
];

pub static TRACE_STAT: [usize; 1] = [4];

pub static TRACE_LSTAT: [usize; 1] = [6];

pub static TRACE_FSTAT: [usize; 3] = [5, 262, 332];

pub static TRACE_STAT_LIKE: [usize; 5] = [4, 5, 6, 262, 332];

pub static TRACE_STATFS: [usize; 1] = [137];

pub static TRACE_FSTATFS: [usize; 1] = [138];

pub static TRACE_STATFS_LIKE: [usize; 3] = [136, 137, 138];

pub static TRACE_PURE: [usize; 8] = [39, 102, 104, 107, 108, 110, 111, 186];

pub static TRACE_CREDS: [usize; 19] = [
    102, 104, 105, 106, 107, 108, 113, 114, 115, 116, 117, 118, 119, 120, 122, 123, 125, 126, 157,
];

pub static TRACE_CLOCK: [usize; 8] = [96, 159, 164, 201, 227, 228, 229, 305];

pub static SYSTEM_CALLS: [(
    &str,
    SystemCallArgumentType,
    SystemCallArgumentType,
    SystemCallArgumentType,
    SystemCallArgumentType,
    SystemCallArgumentType,
    SystemCallArgumentType,
); 335] = [
    (
        "read",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "write",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "open",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "close",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "stat",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fstat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "lstat",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "poll",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "lseek",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mmap",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "mprotect",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "munmap",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "brk",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_sigaction",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_sigprocmask",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_sigreturn",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "ioctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pread64",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pwrite64",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "readv",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "writev",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "access",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pipe",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "select",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
    ),
    (
        "sched_yield",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mremap",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
    ),
    (
        "msync",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mincore",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "madvise",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "shmget",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "shmat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "shmctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "dup",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "dup2",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pause",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "nanosleep",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getitimer",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "alarm",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setitimer",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getpid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sendfile",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "socket",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "connect",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "accept",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sendto",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "recvfrom",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
    ),
    (
        "sendmsg",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "recvmsg",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "shutdown",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "bind",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "listen",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getsockname",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getpeername",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "socketpair",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setsockopt",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "getsockopt",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
    ),
    (
        "clone",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fork",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "vfork",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "execve",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "exit",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "wait4",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "kill",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "uname",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "semget",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "semop",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "semctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "shmdt",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "msgget",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "msgsnd",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "msgrcv",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "msgctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fcntl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "flock",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fsync",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fdatasync",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "truncate",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "ftruncate",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getdents",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getcwd",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "chdir",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fchdir",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rename",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mkdir",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rmdir",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "creat",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "link",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "unlink",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "symlink",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "readlink",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "chmod",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fchmod",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "chown",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fchown",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "lchown",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "umask",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "gettimeofday",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getrlimit",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getrusage",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sysinfo",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "times",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "ptrace",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getuid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "syslog",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getgid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setuid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setgid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "geteuid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getegid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setpgid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getppid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getpgrp",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setsid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setreuid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setregid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getgroups",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setgroups",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setresuid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getresuid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setresgid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getresgid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getpgid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setfsuid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setfsgid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getsid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "capget",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "capset",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_sigpending",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_sigtimedwait",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_sigqueueinfo",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_sigsuspend",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sigaltstack",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "utime",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mknod",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "uselib",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "personality",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "ustat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "statfs",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fstatfs",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sysfs",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getpriority",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setpriority",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_setparam",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_getparam",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_setscheduler",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_getscheduler",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_get_priority_max",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_get_priority_min",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_rr_get_interval",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mlock",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "munlock",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mlockall",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "munlockall",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "vhangup",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "modify_ldt",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pivot_root",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "_sysctl",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "prctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "arch_prctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "adjtimex",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setrlimit",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "chroot",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sync",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "acct",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "settimeofday",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mount",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
    ),
    (
        "umount2",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "swapon",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "swapoff",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "reboot",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sethostname",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setdomainname",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "iopl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "ioperm",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "create_module",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "init_module",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "delete_module",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "get_kernel_syms",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "query_module",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "quotactl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "nfsservctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getpmsg",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "putpmsg",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "afs_syscall",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "tuxcall",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "security",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "gettid",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "readahead",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setxattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "lsetxattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "fsetxattr",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "getxattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "lgetxattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fgetxattr",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "listxattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "llistxattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "flistxattr",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "removexattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "lremovexattr",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fremovexattr",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "tkill",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "time",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "futex",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "sched_setaffinity",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_getaffinity",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "set_thread_area",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "io_setup",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "io_destroy",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "io_getevents",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "io_submit",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "io_cancel",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "get_thread_area",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "lookup_dcookie",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "epoll_create",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "epoll_ctl_old",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "epoll_wait_old",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "remap_file_pages",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "getdents64",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "set_tid_address",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "restart_syscall",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "semtimedop",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fadvise64",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timer_create",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timer_settime",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timer_gettime",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timer_getoverrun",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timer_delete",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "clock_settime",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "clock_gettime",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "clock_getres",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "clock_nanosleep",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "exit_group",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "epoll_wait",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "epoll_ctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "tgkill",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "utimes",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "vserver",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mbind",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "set_mempolicy",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "get_mempolicy",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "mq_open",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mq_unlink",
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mq_timedsend",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mq_timedreceive",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
    ),
    (
        "mq_notify",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mq_getsetattr",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "kexec_load",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "waitid",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "add_key",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "request_key",
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "keyctl",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "ioprio_set",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "ioprio_get",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "inotify_init",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "inotify_add_watch",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "inotify_rm_watch",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "migrate_pages",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "openat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mkdirat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mknodat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fchownat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "futimesat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "newfstatat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "unlinkat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "renameat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "linkat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "symlinkat",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "readlinkat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fchmodat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "faccessat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pselect6",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
    ),
    (
        "ppoll",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "unshare",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "set_robust_list",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "get_robust_list",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "splice",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "tee",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sync_file_range",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "vmsplice",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "move_pages",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "utimensat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "epoll_pwait",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "signalfd",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timerfd_create",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "eventfd",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fallocate",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timerfd_settime",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "timerfd_gettime",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "accept4",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "signalfd4",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "eventfd2",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "epoll_create1",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "dup3",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pipe2",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "inotify_init1",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "preadv",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pwritev",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rt_tgsigqueueinfo",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "perf_event_open",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "recvmmsg",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
    ),
    (
        "fanotify_init",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "fanotify_mark",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
    ),
    (
        "prlimit64",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "name_to_handle_at",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "open_by_handle_at",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "clock_adjtime",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "syncfs",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sendmmsg",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "setns",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getcpu",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "process_vm_readv",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "process_vm_writev",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "kcmp",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "finit_module",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_setattr",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "sched_getattr",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "renameat2",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "seccomp",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "getrandom",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "memfd_create",
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "kexec_file_load",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "bpf",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "execveat",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "userfaultfd",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "membarrier",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "mlock2",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "copy_file_range",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
    ),
    (
        "preadv2",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "pwritev2",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
    ),
    (
        "pkey_mprotect",
        SystemCallArgumentType::Address,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pkey_alloc",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "pkey_free",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "statx",
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::Integer,
        SystemCallArgumentType::String,
        SystemCallArgumentType::None,
    ),
    (
        "io_pgetevents",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
    (
        "rseq",
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
        SystemCallArgumentType::None,
    ),
];
